LossyWrap

Struct LossyWrap 

#[repr(transparent)]
pub struct LossyWrap<T>(pub T);
A lossy wrapper for a TryWriteable that implements Writeable and ignores any errors.

Tuple Fields

0: T

Implementations

Source

impl<T: TryWriteable> LossyWrap<T>

pub fn to_string(&self) -> String

Converts the given value to a String.

Under the hood, this uses an efficient Writeable implementation.

If you don’t need an allocated String, but e.g. need to write this to some sink, it is more efficient to use Writeable directly.